@@ -925,7 +925,7 @@ class HappyVerify(Base):
             raise Exception(">>> ERROR PARAM: num_abc", num_abc)
         num_abc = str(num_abc)
         whether_train = True
-        num = num_abc[0]
+        num = num_abc[:2]
         sess = get_session()
         issue_all = HappyNumber.get_issues()
         issue_last = issue_all[-last_num:]
@@ -933,12 +933,12 @@ class HappyVerify(Base):
         coll_verify_all = []
         for i_target in issue_last:
             i_num_abc = f'{i_target}{num_abc}'
-            v_ins = sess.query(cls).get(i_num_abc)
-            coll_verify.append(v_ins.verify)
+            v = sess.query(cls).get(i_num_abc)
+            coll_verify.append(v.verify)
             temp_dict = {
-                'num123': f'{v_ins.num1}{v_ins.num2}{v_ins.num3}',
-                'result': v_ins.result,
-                'verify': v_ins.verify
+                'num123': HappyNumber.get_one(i_target),
+                'result': v.result,
+                'verify': v.verify
             }
             coll_verify_all.append(temp_dict)
             print(f'model: {num_abc}, result: {temp_dict}')
@@ -949,7 +949,7 @@ class HappyVerify(Base):
 
             # 检查 出号必y
             for one_coll in coll_verify_all:
-                if one_coll['num123'].find(str(num)) > -1:
+                if num in one_coll['num123']:
                     if one_coll['verify'] == 'n':
                         whether_train = True
 
