@@ -1235,15 +1235,15 @@ class SportVerifyX(Base):
             # print("i_num_abc: ", i_num_abc)
             v_ins = sess.query(cls).get(i_num_abc)
             coll_verify.append(v_ins.verify)
-            if cls.__tablename__ == 'verifya':
+            if cls.__tablename__ == 'p5_verifya':
                 temp_num123 = str(v_ins.num1)
-            elif cls.__tablename__ == 'verifyb':
+            elif cls.__tablename__ == 'p5_verifyb':
                 temp_num123 = str(v_ins.num2)
-            elif cls.__tablename__ == 'verifyc':
+            elif cls.__tablename__ == 'p5_verifyc':
                 temp_num123 = str(v_ins.num3)
-            elif cls.__tablename__ == 'verifyd':
+            elif cls.__tablename__ == 'p5_verifyd':
                 temp_num123 = str(v_ins.num4)
-            elif cls.__tablename__ == 'verifye':
+            elif cls.__tablename__ == 'p5_verifye':
                 temp_num123 = str(v_ins.num5)
             else:
                 raise(">>> ERROR TABLENAME")
